"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.json = void 0;
const ActionParameters_1 = require("../ActionParameters");
const secure_json_parse_1 = __importDefault(require("secure-json-parse"));
const json = () => ({
    /**
     * A description of the JSON action format.
     */
    description: "JSON",
    /**
     * Formats the given action parameters into a JSON string.
     *
     * @param parameters - The action parameters to format.
     * @returns The formatted JSON string.
     */
    format(parameters) {
        return JSON.stringify(parameters, null, 2);
    },
    /**
     * Parses the given text into action parameters, handling JSON objects and free text.
     *
     * @param text - The text to parse.
     * @returns The parsed action parameters.
     */
    parse(text) {
        if (!text.trim().endsWith("}")) {
            return { _freeText: text };
        }
        try {
            const firstOpeningBraceIndex = text.indexOf("{");
            const freeText = text.slice(0, firstOpeningBraceIndex);
            const jsonText = text.slice(firstOpeningBraceIndex);
            const jsonObject = secure_json_parse_1.default.parse(jsonText);
            return {
                ...ActionParameters_1.actionParametersSchema.parse(jsonObject),
                _freeText: freeText.trim(),
            };
        }
        catch (error) {
            throw new Error(`${text} could not be parsed as JSON: ${error?.message ?? error}`);
        }
    },
});
exports.json = json;
//# sourceMappingURL=json.js.map