"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Run = void 0;
const createNextId_1 = require("../util/createNextId");
class Run {
    constructor({ controller, observer, initialState, }) {
        this.nextId = (0, createNextId_1.createNextId)(1);
        this.recordedCalls = [];
        this.controller = controller;
        this.observer = observer;
        this.state = initialState;
    }
    generateId({ type }) {
        return `${this.nextId()}-${type}`;
    }
    checkCancel() {
        return this.controller.checkCancel(this);
    }
    logError(error) {
        console.error(error); // TODO logger
    }
    onLoopIterationStarted({ loop }) {
        try {
            this.observer?.onLoopIterationStarted?.({ run: this, loop });
        }
        catch (error) {
            this.logError(error);
        }
    }
    onLoopIterationFinished({ loop }) {
        try {
            this.observer?.onLoopIterationFinished?.({ run: this, loop });
        }
        catch (error) {
            this.logError(error);
        }
    }
    onStepExecutionStarted({ step }) {
        try {
            this.observer?.onStepExecutionStarted?.({ run: this, step });
        }
        catch (error) {
            this.logError(error);
        }
    }
    onStepExecutionFinished({ step, result, }) {
        try {
            this.observer?.onStepExecutionFinished?.({ run: this, step, result });
        }
        catch (error) {
            this.logError(error);
        }
    }
    onStart() {
        try {
            this.observer?.onRunStarted?.({ run: this });
        }
        catch (error) {
            this.logError(error);
        }
    }
    onFinish({ result }) {
        try {
            this.observer?.onRunFinished?.({ run: this, result });
        }
        catch (error) {
            this.logError(error);
        }
    }
    onStepGenerationStarted() {
        try {
            this.observer?.onStepGenerationStarted?.({ run: this });
        }
        catch (error) {
            this.logError(error);
        }
    }
    onStepGenerationFinished({ generatedText, step, }) {
        try {
            this.observer?.onStepGenerationFinished?.({
                run: this,
                generatedText,
                step,
            });
        }
        catch (error) {
            this.logError(error);
        }
    }
    recordCall(call) {
        // TODO associate with currently active step
        this.recordedCalls.push(call);
    }
}
exports.Run = Run;
//# sourceMappingURL=Run.js.map