"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.showRunInConsole = void 0;
const chalk_1 = __importDefault(require("chalk"));
const BasicToolStep_1 = require("../../tool/BasicToolStep");
const log = console.log;
const showRunInConsole = ({ name, }) => ({
    onRunStarted({ run }) {
        log(chalk_1.default.green(`### ${name} ###`));
        log(run.state);
        log();
    },
    onRunFinished({ result }) {
        if (result.type === "cancelled") {
            log(chalk_1.default.gray(`Cancelled: ${result.reason}`));
            return;
        }
        log(chalk_1.default.gray("Done"));
        log(result);
    },
    onStepGenerationStarted() {
        log(chalk_1.default.gray("Thinking…"));
    },
    onStepGenerationFinished({ generatedText }) {
        log(chalk_1.default.cyanBright(generatedText));
        log();
    },
    onStepExecutionStarted({ step }) {
        if (step instanceof BasicToolStep_1.BasicToolStep) {
            log(chalk_1.default.gray(`Executing ${step.type}…`));
            return;
        }
    },
    onStepExecutionFinished({ step }) {
        if (step instanceof BasicToolStep_1.BasicToolStep) {
            const result = step.state;
            const resultType = result.type;
            switch (resultType) {
                case "succeeded": {
                    log(chalk_1.default.green(step.action.formatResult(result)));
                    log();
                    break;
                }
                case "cancelled": {
                    log(chalk_1.default.yellow("Cancelled"));
                    log();
                    break;
                }
                case "failed": {
                    log(chalk_1.default.red(`ERROR: ${result.error}`));
                    log();
                    break;
                }
                case "pending":
                case "running": {
                    // ignored
                    break;
                }
                default: {
                    const _exhaustiveCheck = resultType;
                    throw new Error(`Unhandled result type: ${resultType}`);
                }
            }
            return;
        }
    },
});
exports.showRunInConsole = showRunInConsole;
//# sourceMappingURL=showRunInConsole.js.map