"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.embed = void 0;
const retryWithExponentialBackoff_1 = require("../util/retryWithExponentialBackoff");
async function embed({ id, model, value, retry = (0, retryWithExponentialBackoff_1.retryWithExponentialBackoff)(), }, context) {
    const startTime = performance.now();
    const startEpochSeconds = Math.floor((performance.timeOrigin + startTime) / 1000);
    const rawOutput = await retry(() => model.embed(value));
    const textGenerationDurationInMs = Math.ceil(performance.now() - startTime);
    const metadata = {
        id,
        model: {
            vendor: model.vendor,
            name: model.name,
        },
        startEpochSeconds,
        durationInMs: textGenerationDurationInMs,
        tries: rawOutput.tries,
    };
    if (!rawOutput.success) {
        context?.recordCall?.({
            type: "embed",
            success: false,
            metadata,
            input: value,
            error: rawOutput.error,
        });
        throw rawOutput.error; // TODO wrap error
    }
    const embedding = await model.extractEmbedding(rawOutput.result);
    context?.recordCall?.({
        type: "embed",
        success: true,
        metadata,
        input: value,
        rawOutput: rawOutput.result,
        embedding,
    });
    return embedding;
}
exports.embed = embed;
embed.asFunction =
    ({ id, model, }) => async ({ value }, context) => embed({ id, model, value }, context);
//# sourceMappingURL=embed.js.map