"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recentStepsChatPrompt = void 0;
const step_1 = require("../step");
const BasicToolStep_1 = require("../tool/BasicToolStep");
const recentStepsChatPrompt = ({ maxSteps = 10 }) => async ({ completedSteps, generatedTextsByStepId, }) => {
    const messages = [];
    for (const step of completedSteps.slice(-maxSteps)) {
        // repeat the original agent response to reinforce the action format and keep the conversation going:
        const generatedText = generatedTextsByStepId.get(step.id);
        if (generatedText != null) {
            messages.push({
                role: "assistant",
                content: generatedText,
            });
        }
        let content = undefined;
        const stepState = step.state;
        switch (stepState.type) {
            case "failed": {
                content = `ERROR:\n${stepState.summary}`;
                break;
            }
            case "succeeded": {
                if (step instanceof step_1.NoopStep && step.isDoneStep()) {
                    content = stepState.summary;
                }
                else if (step instanceof BasicToolStep_1.BasicToolStep) {
                    content = step.action.formatResult({
                        input: stepState.input,
                        output: stepState.output,
                        summary: stepState.summary,
                    });
                }
                else if (step instanceof step_1.GenerateNextStepLoop) {
                    content = stepState.summary;
                }
                break;
            }
        }
        if (content != null) {
            messages.push({
                role: "system",
                content,
            });
        }
    }
    return messages;
};
exports.recentStepsChatPrompt = recentStepsChatPrompt;
//# sourceMappingURL=recentStepsChatPrompt.js.map