"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withOpenAIErrorHandler = exports.OpenAIError = exports.OpenAIErrorDataSchema = void 0;
const axios_1 = require("axios");
const zod_1 = __importDefault(require("zod"));
exports.OpenAIErrorDataSchema = zod_1.default.object({
    error: zod_1.default.object({
        message: zod_1.default.string(),
        type: zod_1.default.string(),
        param: zod_1.default.any().nullable(),
        code: zod_1.default.string(),
    }),
});
class OpenAIError extends Error {
    constructor({ error: { message, code, type } }) {
        super(message);
        this.code = code;
        this.type = type;
    }
}
exports.OpenAIError = OpenAIError;
const withOpenAIErrorHandler = async (fn) => {
    try {
        return await fn();
    }
    catch (error) {
        if (error instanceof axios_1.AxiosError) {
            const parsedError = exports.OpenAIErrorDataSchema.safeParse(error?.response?.data);
            if (parsedError.success) {
                throw new OpenAIError(parsedError.data);
            }
        }
        throw error;
    }
};
exports.withOpenAIErrorHandler = withOpenAIErrorHandler;
//# sourceMappingURL=OpenAIError.js.map