"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateOpenAICallCostInMillicent = void 0;
const OpenAIChatCompletion_1 = require("../api/OpenAIChatCompletion");
const OpenAIEmbedding_1 = require("../api/OpenAIEmbedding");
const OpenAITextCompletion_1 = require("../api/OpenAITextCompletion");
const calculateChatCompletionCostInMillicent_1 = require("./calculateChatCompletionCostInMillicent");
const calculateEmbeddingCostInMillicent_1 = require("./calculateEmbeddingCostInMillicent");
const calculateTextCompletionCostInMillicent_1 = require("./calculateTextCompletionCostInMillicent");
function calculateOpenAICallCostInMillicent(call) {
    if (call.metadata.model.vendor !== "openai") {
        throw new Error(`Incorrect vendor: ${call.metadata.model.vendor}`);
    }
    const type = call.type;
    switch (type) {
        case "generate": {
            const model = call.metadata.model.name;
            switch (model) {
                case "gpt-3.5-turbo":
                case "gpt-4": {
                    return (0, calculateChatCompletionCostInMillicent_1.calculateChatCompletionCostInMillicent)({
                        model,
                        output: OpenAIChatCompletion_1.OpenAIChatCompletionSchema.parse(call.rawOutput),
                    });
                }
                case "text-davinci-003":
                case "text-davinci-002":
                case "code-davinci-002":
                case "text-curie-001":
                case "text-babbage-001":
                case "text-ada-001":
                case "davinci":
                case "curie":
                case "babbage":
                case "ada": {
                    return (0, calculateTextCompletionCostInMillicent_1.calculateTextCompletionCostInMillicent)({
                        model,
                        output: OpenAITextCompletion_1.OpenAITextCompletionSchema.parse(call.rawOutput),
                    });
                }
                default: {
                    throw new Error(`Unknown model: ${model}`);
                }
            }
        }
        case "embed": {
            const model = call.metadata.model.name;
            switch (model) {
                case "text-embedding-ada-002": {
                    return (0, calculateEmbeddingCostInMillicent_1.calculateEmbeddingCostInMillicent)({
                        model,
                        output: OpenAIEmbedding_1.OpenAIEmbeddingSchema.parse(call.rawOutput),
                    });
                }
                default: {
                    throw new Error(`Unknown model: ${model}`);
                }
            }
        }
        default: {
            const _exhaustiveCheck = type;
            throw new Error(`Unknown type: ${_exhaustiveCheck}`);
        }
    }
}
exports.calculateOpenAICallCostInMillicent = calculateOpenAICallCostInMillicent;
//# sourceMappingURL=calculateOpenAICallCostInMillicent.js.map