"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.forTiktokenEncoder = exports.forEncoding = exports.forModel = void 0;
const tiktoken_1 = require("@dqbd/tiktoken");
function forModel({ model }) {
    return forTiktokenEncoder({
        encoder: () => (0, tiktoken_1.encoding_for_model)(model),
    });
}
exports.forModel = forModel;
function forEncoding({ encoding, }) {
    return forTiktokenEncoder({ encoder: () => (0, tiktoken_1.get_encoding)(encoding) });
}
exports.forEncoding = forEncoding;
function forTiktokenEncoder({ encoder: createEncoder, }) {
    const textDecoder = new TextDecoder();
    return {
        encode: async (text) => {
            const encoder = createEncoder();
            try {
                const tokens = encoder.encode(text);
                const tokenTexts = [];
                for (const token of tokens) {
                    tokenTexts.push(textDecoder.decode(encoder.decode_single_token_bytes(token)));
                }
                return {
                    tokens,
                    texts: tokenTexts,
                };
            }
            finally {
                encoder.free();
            }
        },
        decode: async (tokens) => {
            const encoder = createEncoder();
            try {
                return textDecoder.decode(encoder.decode(tokens));
            }
            finally {
                encoder.free();
            }
        },
    };
}
exports.forTiktokenEncoder = forTiktokenEncoder;
//# sourceMappingURL=tokenizer.js.map