#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const accepts_1 = __importDefault(require("@fastify/accepts"));
const websocket_1 = __importDefault(require("@fastify/websocket"));
const commander_1 = require("commander");
const dotenv_1 = __importDefault(require("dotenv"));
const fastify_1 = __importDefault(require("fastify"));
const fastify_type_provider_zod_1 = require("fastify-type-provider-zod");
const hyperid_1 = __importDefault(require("hyperid"));
const node_fs_1 = __importDefault(require("node:fs"));
const node_path_1 = __importDefault(require("node:path"));
const pino_1 = __importDefault(require("pino"));
const gracefullyShutdownOnSigTermAndSigInt_1 = require("../util/gracefullyShutdownOnSigTermAndSigInt");
const AgentPlugin_1 = require("./AgentPlugin");
dotenv_1.default.config();
const program = new commander_1.Command();
program
    .description("JS Agent server")
    .addOption(new commander_1.Option("-h, --host <string>", "host name")
    .env("JS_AGENT_HOST")
    .default("127.0.0.1"))
    .addOption(new commander_1.Option("-p, --port <number>", "port number")
    .env("JS_AGENT_PORT")
    .default("30800")
    .argParser((value) => +value))
    .addOption(new commander_1.Option("-f, --folder <string>", "folder with agent specifications in subdirectories")
    .env("JS_AGENT_PATH")
    .makeOptionMandatory())
    .parse(process.argv);
const programArguments = program.opts();
const logger = (0, pino_1.default)({
    level: "info",
    messageKey: "message",
    transport: {
        target: "pino-pretty",
        options: {
            colorize: true,
        },
    },
});
const agentBaseFolder = node_path_1.default.join(process.cwd(), programArguments.folder);
if (!node_fs_1.default.existsSync(agentBaseFolder)) {
    logger.error(`Agent base folder ${agentBaseFolder} does not exist. Exiting.`);
    process.exit(1);
}
// catch uncaught exceptions (to prevent the process from crashing)
process.on("uncaughtException", (error) => {
    logger.error(error, "Uncaught error.");
});
(async () => {
    logger.info(`Starting JS Agent server.`);
    const server = (0, fastify_1.default)({
        logger,
        // Generate custom request IDs. This is required to distinguish between
        // requests made on different pods in a Kubernetes cluster.
        genReqId: (0, hyperid_1.default)(),
        // Unified key for the request ID in the logs:
        requestIdLogLabel: "requestId",
    });
    await server.register(websocket_1.default);
    await server.register(accepts_1.default);
    server.setValidatorCompiler(fastify_type_provider_zod_1.validatorCompiler);
    server.setSerializerCompiler(fastify_type_provider_zod_1.serializerCompiler);
    (0, gracefullyShutdownOnSigTermAndSigInt_1.gracefullyShutdownOnSigTermAndSigInt)({
        logger,
        shutdown: async () => {
            await server.close(); // wait for requests to be finished
            logger.info("JS Agent server stopped.");
        },
    });
    // set up agents:
    const agentFolderNames = node_fs_1.default
        .readdirSync(agentBaseFolder, { withFileTypes: true })
        .filter((agentFolder) => agentFolder.isDirectory())
        .map((agentFolder) => agentFolder.name);
    for (const agentName of agentFolderNames) {
        const agentDefinitionPath = node_path_1.default.join(agentBaseFolder, agentName, "agent.js");
        if (!node_fs_1.default.existsSync(agentDefinitionPath)) {
            logger.warn(`Agent definition file not found at ${agentDefinitionPath}. Skipping.`);
            continue;
        }
        server.register((0, AgentPlugin_1.AgentPlugin)({
            name: agentName,
            specification: (await Promise.resolve(`${agentDefinitionPath}`).then(s => __importStar(require(s)))).default,
        }));
    }
    await server.listen({
        host: programArguments.host,
        port: programArguments.port,
    });
    logger.info(`JS Agent server started.`);
})().catch((error) => {
    logger.error(error);
});
//# sourceMappingURL=startAgentServer.js.map