import { AnyAction } from "../action/Action";
import { ActionRegistry } from "../action/ActionRegistry";
import { ActionFormat } from "../action/format/ActionFormat";
import { Run } from "../agent/Run";
import { RunContext } from "../agent/RunContext";
import { Prompt } from "../prompt/Prompt";
import { GeneratorModel } from "../text/generate/GeneratorModel";
import { Loop } from "./Loop";
import { Step } from "./Step";
import { StepFactory } from "./StepFactory";
export type GenerateNextStepLoopContext<RUN_STATE> = {
    runState: RUN_STATE;
    actions: ActionRegistry<RUN_STATE>;
    completedSteps: Array<Step<RUN_STATE>>;
    generatedTextsByStepId: Map<string, string>;
};
export declare const generateNextStepLoop: <PROMPT_TYPE, RUN_STATE>({ type, actions, actionFormat, doneAction, prompt, model, }: {
    type?: string | undefined;
    doneAction?: AnyAction<RUN_STATE> | undefined;
    actions: AnyAction<RUN_STATE>[];
    actionFormat: ActionFormat;
    prompt: Prompt<GenerateNextStepLoopContext<RUN_STATE>, PROMPT_TYPE>;
    model: GeneratorModel<PROMPT_TYPE, any, string>;
}) => StepFactory<RUN_STATE>;
type NextStepLoopGenerateTextFunction<RUN_STATE> = (_0: GenerateNextStepLoopContext<RUN_STATE>, _1: RunContext) => PromiseLike<string>;
export declare class GenerateNextStepLoop<PROMPT_TYPE, RUN_STATE> extends Loop<RUN_STATE> {
    private readonly generatedTextsByStepId;
    readonly actionRegistry: ActionRegistry<RUN_STATE>;
    readonly generateText: NextStepLoopGenerateTextFunction<RUN_STATE>;
    constructor({ type, run, doneAction, actions, actionFormat, prompt, model, }: {
        type?: string;
        run: Run<RUN_STATE>;
        doneAction?: AnyAction<RUN_STATE>;
        actions: AnyAction<RUN_STATE>[];
        actionFormat: ActionFormat;
        prompt: Prompt<GenerateNextStepLoopContext<RUN_STATE>, PROMPT_TYPE>;
        model: GeneratorModel<PROMPT_TYPE, any, string>;
    });
    private get lastStep();
    protected hasMoreSteps(): boolean;
    protected getResult(): Promise<({
        type: "cancelled";
        reason?: string | undefined;
    } & {
        type: "failed" | "succeeded" | "cancelled";
    }) | ({
        type: "succeeded";
        summary: string;
        input?: unknown;
        output?: unknown;
    } & {
        type: "failed" | "succeeded" | "cancelled";
    }) | ({
        type: "failed";
        summary: string;
        input?: unknown;
        error: unknown;
    } & {
        type: "failed" | "succeeded" | "cancelled";
    })>;
    getNextStep(): Promise<Step<RUN_STATE>>;
}
export {};
