"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerateNextStepLoop = exports.generateNextStepLoop = void 0;
const ActionRegistry_1 = require("../action/ActionRegistry");
const generateText_1 = require("../text/generate/generateText");
const ErrorStep_1 = require("./ErrorStep");
const Loop_1 = require("./Loop");
const NoopStep_1 = require("./NoopStep");
const createActionStep_1 = require("./createActionStep");
const generateNextStepLoop = ({ type, actions, actionFormat, doneAction, prompt, model, }) => async (run) => new GenerateNextStepLoop({
    type,
    run,
    actions,
    actionFormat,
    prompt,
    model,
});
exports.generateNextStepLoop = generateNextStepLoop;
class GenerateNextStepLoop extends Loop_1.Loop {
    constructor({ type = "loop.generate-next-step", run, doneAction, actions, actionFormat, prompt, model, }) {
        super({ type, run });
        this.generatedTextsByStepId = new Map();
        if (prompt == null) {
            throw new Error("prompt is required");
        }
        if (model == null) {
            throw new Error("model is required");
        }
        this.actionRegistry = new ActionRegistry_1.ActionRegistry({
            doneAction,
            actions,
            format: actionFormat,
        });
        this.generateText = generateText_1.generateText.asFunction({
            id: `step/${this.id}/generate-text`,
            prompt,
            model,
            processOutput: async (output) => output,
        });
    }
    get lastStep() {
        return this.completedSteps[this.completedSteps.length - 1];
    }
    hasMoreSteps() {
        return !this.lastStep?.isDoneStep();
    }
    async getResult() {
        return this.lastStep?.isDoneStep()
            ? this.lastStep.state
            : super.getResult();
    }
    async getNextStep() {
        this.run.onStepGenerationStarted();
        const generatedText = await this.generateText({
            runState: this.run.state,
            actions: this.actionRegistry,
            completedSteps: this.completedSteps,
            generatedTextsByStepId: this.generatedTextsByStepId,
        }, this.run);
        const actionParameters = this.actionRegistry.format.parse(generatedText);
        let step;
        if (actionParameters.action == null) {
            step = new NoopStep_1.NoopStep({
                type: "thought",
                run: this.run,
                summary: actionParameters._freeText ?? "",
            });
        }
        else {
            try {
                const action = this.actionRegistry.getAction(actionParameters.action);
                step = await (0, createActionStep_1.createActionStep)({
                    action,
                    input: actionParameters,
                    run: this.run,
                });
            }
            catch (error) {
                step = new ErrorStep_1.ErrorStep({ run: this.run, error });
            }
        }
        this.generatedTextsByStepId.set(step.id, generatedText);
        this.run.onStepGenerationFinished({ generatedText, step });
        return step;
    }
}
exports.GenerateNextStepLoop = GenerateNextStepLoop;
//# sourceMappingURL=GenerateNextStepLoop.js.map