"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Loop = void 0;
const Step_1 = require("./Step");
class Loop extends Step_1.Step {
    constructor({ type, run }) {
        super({ type, run });
        this.completedSteps = [];
    }
    async update({ step, result, }) {
        return Promise.resolve();
    }
    async getResult() {
        return { type: "succeeded", summary: "Completed all tasks." };
    }
    async _execute() {
        try {
            while (this.hasMoreSteps()) {
                const cancelCheck = this.run.checkCancel();
                if (cancelCheck.shouldCancel) {
                    return { type: "cancelled", reason: cancelCheck.reason };
                }
                this.run.onLoopIterationStarted({ loop: this });
                const step = await this.getNextStep();
                const result = await step.execute();
                this.completedSteps.push(step);
                if (result.type === "cancelled") {
                    return result;
                }
                await this.update({ step, result });
                this.run.onLoopIterationFinished({ loop: this });
            }
        }
        catch (error) {
            return {
                type: "failed",
                summary: `Failed to run step`,
                error,
            };
        }
        return this.getResult();
    }
    getStepCount() {
        return this.completedSteps.reduce((sum, step) => sum + step.getStepCount(), 0);
    }
}
exports.Loop = Loop;
//# sourceMappingURL=Loop.js.map