"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Step = void 0;
class Step {
    constructor({ type, run }) {
        if (type == null) {
            throw new Error(`Step type is required`);
        }
        if (run == null) {
            throw new Error(`Step run is required`);
        }
        this.type = type;
        this.run = run;
        this.id = run.generateId({ type });
        this.state = { type: "pending" };
    }
    async execute() {
        const cancelCheck = this.run.checkCancel();
        if (cancelCheck.shouldCancel) {
            return { type: "cancelled", reason: cancelCheck.reason };
        }
        if (this.state.type !== "pending") {
            throw new Error(`Step is already running`);
        }
        this.state = { type: "running" };
        this.run.onStepExecutionStarted({ step: this });
        let result;
        try {
            result = await this._execute(this.run);
        }
        catch (error) {
            result = {
                type: "failed",
                summary: error.message ?? "Step failed.",
                error,
            };
        }
        this.state = result;
        this.run.onStepExecutionFinished({ step: this, result });
        return result;
    }
    isDoneStep() {
        return false;
    }
    getStepCount() {
        return 1;
    }
}
exports.Step = Step;
//# sourceMappingURL=Step.js.map