"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InMemoryTextStore = void 0;
const cosineSimilarity_1 = require("../util/cosineSimilarity");
const createNextId_1 = require("../util/createNextId");
class InMemoryTextStore {
    constructor({ embed }) {
        this.nextId = (0, createNextId_1.createNextId)();
        this.texts = new Map();
        this.embed = embed;
    }
    async store({ text }, context) {
        const id = this.nextId();
        const embedding = await this.embed({ value: text }, context);
        this.texts.set(id, { id, embedding, text });
        return { id };
    }
    async retrieve({ query, maxResults = 5, similarityThreshold = 0.5, }, context) {
        const queryEmbedding = await this.embed({ value: query }, context);
        const textSimilarities = [...this.texts.values()]
            .map((entry) => ({
            id: entry.id,
            similarity: (0, cosineSimilarity_1.cosineSimilarity)(entry.embedding, queryEmbedding),
            text: entry.text,
        }))
            .filter((entry) => entry.similarity > similarityThreshold);
        textSimilarities.sort((a, b) => b.similarity - a.similarity);
        return textSimilarities.slice(0, maxResults);
    }
}
exports.InMemoryTextStore = InMemoryTextStore;
//# sourceMappingURL=InMemoryTextStore.js.map