"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractRecursively = void 0;
async function extractRecursively({ extract, split, text, topic, context, }) {
    const chunks = await split({ text });
    const extractedTexts = [];
    for (const chunk of chunks) {
        extractedTexts.push(await extract({ text: chunk, topic }, context));
    }
    if (extractedTexts.length === 1) {
        return extractedTexts[0];
    }
    // recursive summarization: will split joined summaries as needed to stay
    // within the allowed size limit of the splitter.
    return extractRecursively({
        text: extractedTexts.join("\n\n"),
        topic,
        extract,
        split,
        context,
    });
}
exports.extractRecursively = extractRecursively;
extractRecursively.asExtractFunction =
    ({ split, extract, }) => async ({ text, topic }, context) => extractRecursively({
        text,
        topic,
        extract,
        split,
        context,
    });
//# sourceMappingURL=extractRecursively.js.map