"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = void 0;
const retryWithExponentialBackoff_1 = require("../../util/retryWithExponentialBackoff");
async function generate({ id, prompt, input, model, processOutput, retry = (0, retryWithExponentialBackoff_1.retryWithExponentialBackoff)(), }, context) {
    const expandedPrompt = await prompt(input);
    const startTime = performance.now();
    const startEpochSeconds = Math.floor((performance.timeOrigin + startTime) / 1000);
    const rawOutput = await retry(() => model.generate(expandedPrompt));
    const textGenerationDurationInMs = Math.ceil(performance.now() - startTime);
    const metadata = {
        id,
        model: {
            vendor: model.vendor,
            name: model.name,
        },
        startEpochSeconds,
        durationInMs: textGenerationDurationInMs,
        tries: rawOutput.tries,
    };
    if (!rawOutput.success) {
        context?.recordCall?.({
            type: "generate",
            success: false,
            metadata,
            input: expandedPrompt,
            error: rawOutput.error,
        });
        throw rawOutput.error;
    }
    const extractedOutput = await model.extractOutput(rawOutput.result);
    context?.recordCall?.({
        type: "generate",
        success: true,
        metadata,
        input: expandedPrompt,
        rawOutput: rawOutput.result,
        extractedOutput,
    });
    return processOutput(extractedOutput);
}
exports.generate = generate;
generate.asFunction =
    ({ id, prompt, model, processOutput, retry, }) => async (input, context) => generate({
        id,
        prompt,
        input,
        model,
        processOutput,
        retry,
    }, context);
//# sourceMappingURL=generate.js.map