"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeAskUser = exports.askUser = void 0;
const readline_1 = __importDefault(require("readline"));
const zod_1 = __importDefault(require("zod"));
const askUser = ({ id = "ask-user", description = "Ask the user for input or to take an action.", inputExample = {
    query: "{question or action description}",
}, execute, formatResult = ({ input, output: { response } }) => `${input.query}: ${response}`, }) => ({
    type: "basic-tool",
    id,
    description,
    inputSchema: zod_1.default.object({
        query: zod_1.default.string(),
    }),
    outputSchema: zod_1.default.object({
        response: zod_1.default.string(),
    }),
    inputExample,
    execute,
    formatResult,
});
exports.askUser = askUser;
const executeAskUser = () => async ({ input: { query } }) => {
    const userInput = readline_1.default.createInterface({
        input: process.stdin,
        output: process.stdout,
    });
    const response = await new Promise((resolve) => {
        userInput.question(query, (answer) => {
            resolve(answer);
            userInput.close();
        });
    });
    return {
        summary: `User response: ${response}`,
        output: { response },
    };
};
exports.executeAskUser = executeAskUser;
//# sourceMappingURL=AskUserTool.js.map