"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolRegistry = void 0;
class ToolRegistry {
    constructor({ tools }) {
        this.tools = new Map();
        for (const tool of tools) {
            this.register(tool);
        }
    }
    register(tool) {
        if (this.tools.has(tool.id)) {
            throw new Error(`A tool with the id '${tool.id}' has already been registered.`);
        }
        this.tools.set(tool.id, tool);
    }
    get toolIds() {
        return Array.from(this.tools.keys());
    }
    getTool(id) {
        const tool = this.tools.get(id);
        if (!tool) {
            throw new Error(`No tool '${id}' found. Available tools: ${this.toolIds.join(", ")}`);
        }
        return tool;
    }
}
exports.ToolRegistry = ToolRegistry;
//# sourceMappingURL=ToolRegistry.js.map