"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runToolExecutor = void 0;
const fastify_1 = __importDefault(require("fastify"));
const hyperid_1 = __importDefault(require("hyperid"));
const pino_1 = __importDefault(require("pino"));
const zod_1 = __importDefault(require("zod"));
const gracefullyShutdownOnSigTermAndSigInt_1 = require("../../util/gracefullyShutdownOnSigTermAndSigInt");
const ToolRegistry_1 = require("./ToolRegistry");
const toolPlugin_1 = require("./toolPlugin");
const runToolExecutor = async ({ tools, }) => {
    const environmentSchema = zod_1.default.object({
        WORKSPACE: zod_1.default.string(),
        HOST: zod_1.default.string(),
        PORT: zod_1.default.string(),
    });
    const environment = environmentSchema.parse(process.env);
    const logger = (0, pino_1.default)({
        level: "debug",
        messageKey: "message",
    });
    const server = (0, fastify_1.default)({
        logger,
        genReqId: (0, hyperid_1.default)(),
        requestIdLogLabel: "requestId",
    });
    server.register((0, toolPlugin_1.createToolPlugin)({
        toolRegistry: new ToolRegistry_1.ToolRegistry({ tools }),
        logger,
    }));
    await server.listen({
        host: environment.HOST,
        port: parseInt(environment.PORT),
    });
    logger.info(`Executor service started.`);
    // catch uncaught exceptions (to prevent the process from crashing)
    process.on("uncaughtException", (error) => {
        logger.error(error, "Uncaught error.");
    });
    (0, gracefullyShutdownOnSigTermAndSigInt_1.gracefullyShutdownOnSigTermAndSigInt)({
        logger,
        async shutdown() {
            await server.close(); // wait for requests to be finished
        },
    });
};
exports.runToolExecutor = runToolExecutor;
//# sourceMappingURL=runToolExecutor.js.map