"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createToolPlugin = void 0;
function createToolPlugin({ toolRegistry, logger, }) {
    return async function toolPlugin(fastify) {
        fastify.post("/tool/:toolType", {
            async handler(request, reply) {
                try {
                    const toolType = request.params.toolType;
                    const tool = toolRegistry.getTool(toolType);
                    const input = tool.inputSchema.parse(request.body);
                    const output = await tool.execute({
                        input,
                        action: tool,
                    }, null);
                    const textOutput = JSON.stringify(output);
                    reply.status(200).send(textOutput);
                }
                catch (error) {
                    logger.error(error, "An error occurred while processing the command.");
                    reply.status(500).send({
                        message: "An error occurred while processing the command.",
                        error: error.message,
                    });
                }
            },
        });
    };
}
exports.createToolPlugin = createToolPlugin;
//# sourceMappingURL=toolPlugin.js.map