"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeExtractInformationFromWebpage = exports.extractInformationFromWebpage = void 0;
const zod_1 = __importDefault(require("zod"));
const htmlToText_1 = require("../../convert/htmlToText");
const source_1 = require("../../source");
const text_1 = require("../../text");
const extractInformationFromWebpage = ({ id = "extract-information-from-webpage", description = "Extract information from a webpage considering a topic.", inputExample = {
    topic: "{information that I want to extract from the webpage}",
    url: "{https://www.example.com}",
}, execute, formatResult = ({ input, output: { extractedInformation } }) => `## Extracted information on topic '${input.topic}' from ${input.url}\n${extractedInformation}`, }) => ({
    type: "basic-tool",
    id,
    description,
    inputSchema: zod_1.default.object({
        topic: zod_1.default.string(),
        url: zod_1.default.string(),
    }),
    outputSchema: zod_1.default.object({
        extractedInformation: zod_1.default.string(),
    }),
    inputExample,
    execute,
    formatResult,
});
exports.extractInformationFromWebpage = extractInformationFromWebpage;
const executeExtractInformationFromWebpage = ({ loadText = text_1.load.asFunction({
    using: source_1.webpageAsHtmlText.asFunction(),
    convert: htmlToText_1.htmlToText.asFunction(),
}), extract, }) => async ({ input: { topic, url } }, context) => ({
    summary: `Extracted information on topic ${topic} from website ${url}.`,
    output: {
        extractedInformation: await extract({
            text: await loadText({ url }),
            topic,
        }, context),
    },
});
exports.executeExtractInformationFromWebpage = executeExtractInformationFromWebpage;
//# sourceMappingURL=ExtractInformationFromWebpageTool.js.map