"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeProgrammableGoogleSearchEngineAction = exports.programmableGoogleSearchEngineAction = void 0;
const axios_1 = __importDefault(require("axios"));
const zod_1 = __importDefault(require("zod"));
const programmableGoogleSearchEngineAction = ({ id = "search", description = "Search programmable Google search engine.", inputExample = {
    query: "{search query}",
}, execute, formatResult = ({ summary, output: { results } }) => `## ${summary}\n${results
    .map((result) => `### ${result.title}\n${result.link}\n${result.snippet}\n`)
    .join("\n")}`, }) => ({
    type: "basic-tool",
    id,
    description,
    inputSchema: zod_1.default.object({
        query: zod_1.default.string(),
    }),
    outputSchema: zod_1.default.object({
        results: zod_1.default.array(zod_1.default.object({
            title: zod_1.default.string(),
            link: zod_1.default.string(),
            snippet: zod_1.default.string(),
        })),
    }),
    inputExample,
    execute,
    formatResult,
});
exports.programmableGoogleSearchEngineAction = programmableGoogleSearchEngineAction;
const executeProgrammableGoogleSearchEngineAction = ({ key, cx, maxResults = 5, }) => async ({ input: { query } }) => {
    const result = await axios_1.default.get(`https://www.googleapis.com/customsearch/v1/siterestrict?key=${key}&cx=${cx}&q=${query}`);
    const items = result.data.items.slice(0, maxResults);
    return {
        summary: `Found ${items.length} search results.`,
        output: {
            results: items.map((item) => ({
                title: item.title,
                link: item.link,
                snippet: item.snippet,
            })),
        },
    };
};
exports.executeProgrammableGoogleSearchEngineAction = executeProgrammableGoogleSearchEngineAction;
//# sourceMappingURL=ProgrammableGoogleSearchEngineTool.js.map