"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeRunCommand = exports.runCommand = void 0;
const child_process_1 = require("child_process");
const zod_1 = __importDefault(require("zod"));
const runCommand = ({ id = "run-command", description = `Run a shell command. The output is shown. Useful commands include:
- ls: list files
- mv: move and rename files`, inputExample = {
    command: "{command}",
}, execute, formatResult = ({ summary, output: { stdout, stderr } }) => {
    const stdoutText = stdout.trim() !== "" ? `\n### stdout\n${stdout.trim()}` : "";
    const stderrText = stderr.trim() !== "" ? `\n### stderr\n${stderr.trim()}` : "";
    return `## ${summary}${stdoutText}${stderrText}`;
}, }) => ({
    type: "basic-tool",
    id,
    description,
    inputSchema: zod_1.default.object({
        command: zod_1.default.string(),
    }),
    outputSchema: zod_1.default.object({
        stdout: zod_1.default.string(),
        stderr: zod_1.default.string(),
    }),
    inputExample,
    execute,
    formatResult,
});
exports.runCommand = runCommand;
const executeRunCommand = ({ workspacePath, }) => async ({ input: { command } }) => {
    const { stdout, stderr } = await new Promise((resolve, reject) => {
        (0, child_process_1.exec)(command, { cwd: workspacePath }, (error, stdout, stderr) => {
            resolve({
                stdout,
                stderr,
            });
        });
    });
    return {
        summary: `Command ${command} executed successfully`,
        output: {
            stdout,
            stderr,
        },
    };
};
exports.executeRunCommand = executeRunCommand;
//# sourceMappingURL=RunCommandTool.js.map