"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeWriteFile = exports.writeFile = void 0;
const promises_1 = __importDefault(require("node:fs/promises"));
const node_path_1 = __importDefault(require("node:path"));
const zod_1 = __importDefault(require("zod"));
const writeFile = ({ id = "write-file", description = "Write file content.", inputExample = {
    filePath: "{file path relative to the workspace folder}",
    content: "{new file content}",
}, execute, formatResult = ({ summary, output: { content } }) => `## ${summary}\n### New file content\n${content}`, }) => ({
    type: "basic-tool",
    id,
    description,
    inputSchema: zod_1.default.object({
        filePath: zod_1.default.string(),
        content: zod_1.default.string(),
    }),
    outputSchema: zod_1.default.object({
        content: zod_1.default.string(),
    }),
    inputExample,
    execute,
    formatResult,
});
exports.writeFile = writeFile;
const executeWriteFile = ({ workspacePath, }) => async ({ input: { filePath, content } }) => {
    // TODO try-catch
    const fullPath = node_path_1.default.join(workspacePath, filePath);
    await promises_1.default.writeFile(fullPath, content);
    const newContent = await promises_1.default.readFile(fullPath, "utf-8");
    return {
        summary: `Replaced the content of file ${filePath}.`,
        output: { content: newContent },
    };
};
exports.executeWriteFile = executeWriteFile;
//# sourceMappingURL=WriteFileTool.js.map