"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.gracefullyShutdownOnSigTermAndSigInt = void 0;
/**
 * Listens for SIGINT and SIGTERM and terminates the process gracefully.
 *
 * This ensures that running requests, database connections and other operations
 * are finished before the process is terminated.
 */
function gracefullyShutdownOnSigTermAndSigInt({ logger, shutdown, }) {
    async function closeGracefully(signal) {
        logger.info(`Received signal to terminate: ${signal}`);
        await shutdown();
        process.kill(process.pid, signal);
    }
    process.once("SIGINT", closeGracefully);
    process.once("SIGTERM", closeGracefully);
}
exports.gracefullyShutdownOnSigTermAndSigInt = gracefullyShutdownOnSigTermAndSigInt;
//# sourceMappingURL=gracefullyShutdownOnSigTermAndSigInt.js.map