"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.retryNever = exports.retryWithExponentialBackoff = void 0;
const axios_1 = __importDefault(require("axios"));
const retryWithExponentialBackoff = ({ maxTries = 5, delay = 2000 } = {}) => async (f) => _retryWithExponentialBackoff(f, { maxTries, delay });
exports.retryWithExponentialBackoff = retryWithExponentialBackoff;
const retryNever = () => (0, exports.retryWithExponentialBackoff)({ maxTries: 1 });
exports.retryNever = retryNever;
async function _retryWithExponentialBackoff(f, { maxTries = 5, delay = 2000 } = {}, tryNumber = 1) {
    try {
        return {
            success: true,
            tries: tryNumber,
            result: await f(),
        };
    }
    catch (error) {
        if (axios_1.default.isAxiosError(error) &&
            (error.response?.status === 429 || // too many requests
                error.response?.status === 502 ||
                error.response?.status === 520) && // cloudflare error
            maxTries > tryNumber) {
            await new Promise((resolve) => setTimeout(resolve, delay));
            return _retryWithExponentialBackoff(f, { maxTries, delay: 2 * delay }, tryNumber + 1);
        }
        return {
            success: false,
            tries: tryNumber,
            error,
        };
    }
}
//# sourceMappingURL=retryWithExponentialBackoff.js.map